"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateMessagesClient = void 0;
class TemplateMessagesClient {
    constructor(client, onError) {
        this.client = client;
        this.onError = onError;
    }
    /**
     * Get message templates
     * @param config Webhook configuration with URL and optional verify token.
     */
    getMessageTemplates() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { data } = yield this.client.get('/message_templates');
                return data;
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
    addMessageTemplate(data) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.client.post('/message_templates', data);
                return response.data;
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
    deleteMessageTemplate(name) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.client.post('/message_templates?name=' + name);
                return response.data;
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
}
exports.TemplateMessagesClient = TemplateMessagesClient;
