import { AxiosInstance } from 'axios';
import { MessageResponse } from '../types';
export interface ReplyButton {
    type: 'reply';
    reply: {
        id: string;
        title: string;
    };
}
export interface CtaUrlButton {
    type: 'cta_url';
    display_text: string;
    url: string;
}
export interface ButtonMessageOptions {
    to: string;
    body: string;
    footer?: string;
    header?: string;
    buttons: ReplyButton[];
}
export interface CtaMessageOptions {
    to: string;
    body: string;
    footer?: string;
    header?: string;
    button: CtaUrlButton;
}
export interface TemplateMessageOptions {
    to: string;
    name: string;
    language: string;
}
export declare class MessageClient {
    private client;
    private onError?;
    constructor(client: AxiosInstance, onError?: (error: unknown) => void);
    /**
     * Sends a text message.
     */
    sendText(to: string, message: string): Promise<MessageResponse>;
    /**
     * Sends a message with reply buttons.
     */
    sendButtonMessage(options: ButtonMessageOptions): Promise<MessageResponse>;
    /**
     * Sends a message with a CTA URL button.
     */
    sendCtaMessage(options: CtaMessageOptions): Promise<MessageResponse>;
    sendTemplateMessage(options: TemplateMessageOptions): Promise<MessageResponse>;
    readMessage(messageId: string): Promise<MessageResponse>;
    private handleError;
}
