"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookClient = void 0;
class WebhookClient {
    constructor(client, onError) {
        this.client = client;
        this.onError = onError;
    }
    /**
     * Sets up a webhook URL.
     * @param config Webhook configuration with URL and optional verify token.
     */
    setWebhook(config) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.client.post('/webhook', {
                    object: 'whatsapp_business_account',
                    callback_url: config.url,
                    verify_token: config.verify_token || '',
                });
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
    /**
     * Retrieves the current webhook configuration.
     */
    getWebhook() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.client.get('/webhook');
                return response.data;
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
    /**
     * Deletes the current webhook configuration.
     */
    deleteWebhook() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield this.client.delete('/webhook');
            }
            catch (error) {
                if (this.onError)
                    this.onError(error);
                throw error;
            }
        });
    }
}
exports.WebhookClient = WebhookClient;
