"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstagramMessageClient = void 0;
class InstagramMessageClient {
    constructor(client, config) {
        this.config = config;
        this.client = client;
        this.onError = this.config.onError;
    }
    /**
     * Sends a text message.
     */
    sendText(recipientId, message) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const response = yield this.client.post(`/${this.config.phoneNumberId}/messages`, {
                    recipient: {
                        id: recipientId
                    },
                    message: { text: message },
                });
                return response.data;
            }
            catch (error) {
                this.handleError(error.response);
            }
        });
    }
    /**
     * Sends a message with reply buttons.
     */
    sendButtonMessage(options) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // Prepare the body of the request with the reply buttons
                const response = yield this.client.post(`/${this.config.phoneNumberId}/messages`, {
                    messaging_product: 'whatsapp',
                    to: options.to,
                    type: 'interactive',
                    interactive: {
                        type: 'button',
                        body: { text: options.body },
                        footer: options.footer ? { text: options.footer } : undefined,
                        header: options.header ? { type: 'text', text: options.header } : undefined,
                        action: {
                            buttons: options.buttons,
                        },
                    },
                });
                return response.data;
            }
            catch (error) {
                this.handleError(error);
            }
        });
    }
    /**
     * Sends a message with a CTA URL button.
     */
    sendCtaMessage(options) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                // Prepare the body of the request for the CTA URL message
                const response = yield this.client.post(`/${this.config.phoneNumberId}/messages`, {
                    messaging_product: 'whatsapp',
                    to: options.to,
                    type: 'interactive',
                    interactive: {
                        type: 'cta_url',
                        body: { text: options.body },
                        footer: options.footer ? { text: options.footer } : undefined,
                        header: options.header ? { type: 'text', text: options.header } : undefined,
                        action: {
                            name: 'cta_url',
                            parameters: {
                                display_text: options.button.display_text,
                                url: options.button.url,
                            }
                        },
                    },
                });
                return response.data;
            }
            catch (error) {
                this.handleError(error);
            }
        });
    }
    // Error handling utility (can be expanded)
    handleError(error) {
        if (this.onError) {
            this.onError(error);
        }
        else {
            console.error('Error:', error);
        }
    }
}
exports.InstagramMessageClient = InstagramMessageClient;
