import { AxiosInstance } from 'axios';
import { MessageResponse, Session } from '../types';

export interface GenerateTokenParams {
    secretKey: string
}

export interface StartSessionParams {
    webhook: string;
}

export class AuthClient {
    private client: AxiosInstance;

    constructor(client: AxiosInstance) {
        this.client = client;
    }

    async generateToken({ secretKey }: GenerateTokenParams) {
        const response = await this.client.post(`/${secretKey}/generate-token`, { secretKey });
        return response.data;
    }

    async startSession({ webhook }: StartSessionParams): Promise<Session> {
        const response = await this.client.post<Session>(`/start-session`, { webhook, waitQrCode: true });
        return response.data;
    }

    async sessionStatus(): Promise<Session> {
        const response = await this.client.get<Session>(`/status-session`);
        return response.data;
    }

    async getQrCode(): Promise<Session> {
        const response = await this.client.get<Session>(`/qrcode-session`);
        return response.data;
    }

    async closeSession() {
        const response = await this.client.post(`/close-session`);
        return response.data;
    }
}